CarouselBehavior enum
Define what happens when user discards cards.
In loop mode, items will not disappear after being discarded. Instead, it'll be moved to the bottom of the list.
In consume mode, items will be removed from cards after being discard. When all cards has been consumed, an empty placeholder will take place.
Values
- loop → const CarouselBehavior
- consume → const CarouselBehavior
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CarouselBehavior> - A constant List of the values in this enum, in order of their declaration.